import plotly.graph_objects as go
import pandas as pd

# drop sizes off the high end of the list so we can better see the ones we really care about most
numClipsToDisplay=3500 # 0 to disable

aclData = pd.read_csv('FullGroupFive01_ACL_AfterExclusions.csv',sep=',')
predData = pd.read_csv('FullGroupFive01_PredF_AfterExclusions.csv',sep=',')

rowCount = len(aclData['Name'].tolist())
removedClips = False

aclData.sort_values(by='MaxErr', inplace=True)
predData.sort_values(by='MaxErr', inplace=True)

if numClipsToDisplay > 0 and numClipsToDisplay < rowCount:
	aclData = aclData[0:numClipsToDisplay]
	predData = predData[0:numClipsToDisplay]
	rowCount = numClipsToDisplay
	removedClips = True

# Trick to make sure the sorted order from above is drawn correctly
rowNums = list(range(rowCount))
aclData['Order'] = rowNums
predData['Order'] = rowNums

fig = go.Figure()

fig.add_trace(go.Scatter(name='ACL', hovertext=aclData['Name'],
					x=aclData['Order'],
					y=aclData['MaxErr']
					))
					
fig.add_trace(go.Scatter(name='Predictive Flat', hovertext=predData['Name'],
					x=predData['Order'],
					y=predData['MaxErr']
					))

if removedClips:
	title = "Lowest (by max error) " + str(numClipsToDisplay) + " Clips, Ordered By Max Error"
else:
	title = "All Clips Ordered by Max Error"

fig.update_yaxes(rangemode="nonnegative")

fig.update_layout(
    title="Error Distribution",
	xaxis_title=title,
	yaxis_title="Max Error"
)

#cut off the top, it's wasting space
if not removedClips:
	fig.update_layout(
		yaxis_range=(0, 0.5)
	)

fig.show()