import plotly.graph_objects as go
import pandas as pd

# drop sizes off the high end of the list so we can better see the ones we really care about most
numClipsToDisplay=3500 # 0 to disable
maxSizeLimitToDisplay=80000
removeMaxSizeClips_OR_MaxErrorClips = False #True will remove max size clips instead of max error clips to fulfill the numClipsToDisplay

aclData = pd.read_csv('FullGroupFive34_ACL_AfterExclusions.csv',sep=',')
predData = pd.read_csv('FullGroupFive34_PredF_AfterExclusions.csv',sep=',')
simpData = pd.read_csv('FullGroupFive34_Simple_AfterExclusions.csv',sep=',')

rowCount = len(aclData['Name'].tolist())
removedClips = False

if not removeMaxSizeClips_OR_MaxErrorClips:
	#first sort by max error, so the clips we cull out are the ones with the most error, not the most size
	aclData.sort_values(by='MaxErr', inplace=True)
	predData.sort_values(by='MaxErr', inplace=True)
	simpData.sort_values(by='MaxErr', inplace=True)

	if numClipsToDisplay > 0 and numClipsToDisplay < rowCount:
		aclData = aclData[0:numClipsToDisplay]
		predData = predData[0:numClipsToDisplay]
		simpData = simpData[0:numClipsToDisplay]
		rowCount = numClipsToDisplay
		removedClips = True

# Now sort by size for display
aclData.sort_values(by='Size', inplace=True)
predData.sort_values(by='Size', inplace=True)
simpData.sort_values(by='Size', inplace=True)

# if we didn't cull by error above, cull by size now 
if not removedClips and numClipsToDisplay > 0 and numClipsToDisplay < rowCount:
	aclData = aclData[0:numClipsToDisplay]
	predData = predData[0:numClipsToDisplay]
	simpData = simpData[0:numClipsToDisplay]
	rowCount = numClipsToDisplay
	removedClips = True

# simple is missing some items, fill the end with junk if necessary
simpRowCount = len(simpData['Name'].tolist())
if simpRowCount < rowCount:
	lastElem = simpData.iloc[simpRowCount-1]
	appendList = []
	numToAdd = rowCount - simpRowCount
	for x in range(numToAdd):
	  appendList.append(lastElem)
	simpData = simpData.append(other=appendList)
	nameLoc = simpData.columns.get_loc('Name')
	for x in range(numToAdd):
	  simpData.iloc[simpRowCount + x, nameLoc] = 'Removed ' + str(x)

# Trick to make sure the sorted order from above is drawn correctly
rowNums = list(range(rowCount))
aclData['Order'] = rowNums
predData['Order'] = rowNums
simpData['Order'] = rowNums

fig = go.Figure()

fig.add_trace(go.Scatter(name='ACL', hovertext=aclData['Name'],
					x=aclData['Order'],
					y=aclData['Size']
					))
					
fig.add_trace(go.Scatter(name='Predictive Flat', hovertext=predData['Name'],
					x=predData['Order'],
					y=predData['Size']
					))
					
fig.add_trace(go.Scatter(name='Simple', hovertext=simpData['Name'],
					x=simpData['Order'],
					y=simpData['Size']
					))

cullType = "by max size" if removeMaxSizeClips_OR_MaxErrorClips else "by max error"
if removedClips:
	title = "Lowest (" + cullType + ") " + str(numClipsToDisplay) + " Clips, Ordered By Size"
else:
	title = "All Clips Ordered by Size"
	
fig.update_yaxes(rangemode="nonnegative")

fig.update_layout(
    title="Size Distribution",
	xaxis_title=title,
	yaxis_title="Size"
)

#if we only removed maxError clips, there are still some huge sizes we should cut off the top
if not removeMaxSizeClips_OR_MaxErrorClips:
	fig.update_layout(
		yaxis_range=(0, maxSizeLimitToDisplay)
	)

fig.show()